@@ -1,18 +1,15 @@
 import abc
 import numpy as np
-import timeit
 from typing import Any, Dict
 from copy import deepcopy
 
-from ..problem import OptimizationProblem
-from ..state import StateVector
+from ..problem import Problem, StateVector
 
 
 class Solver(abc.ABC):
 
-  def __init__(self, opt_prob: OptimizationProblem, **parameters: Dict[str, Any]) -> None:
-    self._problem = opt_prob
-    self._state_vector = StateVector()
+  def __init__(self, problem: Problem, **parameters: Dict[str, Any]) -> None:
+    self._problem = problem
     # solver parameters
     self._parameters = {
         "verbose": False,
@@ -24,9 +21,7 @@ class Solver(abc.ABC):
     self._parameters.update(**parameters)
 
     # set up state vector -- add all states that are not locked to vector
-    for state_var in self._problem.get_state_vars():
-      if not state_var.is_locked():
-        self._state_vector.add_state_var(state_var)
+    self._state_vector: StateVector = self._problem.get_state_vector()
 
     # create a backup state vector
     self._state_vector_backup = deepcopy(self._state_vector)
@@ -39,34 +34,17 @@ class Solver(abc.ABC):
     self._pending_proposed_state = False
 
   @property
-  def parameters(self) -> Dict[str, Any]:
-    return self._parameters
+  def termination_cause(self) -> str:
+    return self._term
 
   @property
   def curr_iteration(self) -> int:
     return self._curr_iteration
 
-  @property
-  def coverged(self) -> bool:
-    return self._solver_converged
-
-  @property
-  def termination_cause(self) -> str:
-    return self._term
-
   def optimize(self) -> None:
-    # setup timer
-    start = timeit.default_timer()
-
-    # optimization loop
     while not self._solver_converged:
       self.iterate()
 
-    # log
-    if self._parameters["verbose"]:
-      end = timeit.default_timer()
-      print("Total Optimization Time: {0:.4f} seconds".format(end - start))
-
   def iterate(self) -> None:
     # check colver converged
     if self._solver_converged:
